@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 """Constants used in various parts of QL, mostly strings."""
 
@@ -52,20 +53,20 @@ class MinVersions(object):
     """Dependency requirements for Quod Libet / Ex Falso"""
 
     PYTHON2 = Version("Python2", 2, 7)
-    PYTHON3 = Version("Python3", 3, 4)
-    MUTAGEN = Version("Mutagen", 1, 32,
+    PYTHON3 = Version("Python3", 3, 5)
+    MUTAGEN = Version("Mutagen", 1, 34,
         message="Use the Quod Libet unstable PPAs/repos to get a newer "
                 "mutagen version.")
-    GTK = Version("GTK+", 3, 14)
-    PYGOBJECT = Version("PyGObject", 3, 14)
-    GSTREAMER = Version("GStreamer", 1, 4)
+    GTK = Version("GTK+", 3, 18)
+    PYGOBJECT = Version("PyGObject", 3, 18)
+    GSTREAMER = Version("GStreamer", 1, 8)
 
 
-VERSION_TUPLE = Version("", 3, 9, 0)
+VERSION_TUPLE = Version("", 4, 0, 0)
 VERSION = str(VERSION_TUPLE)
 
 # entry point for the user guide / wiki
-BRANCH_NAME = "quodlibet-3.9"
+BRANCH_NAME = "quodlibet-4.0"
 DOCS_BASE_URL = "https://quodlibet.readthedocs.org/en/%s"
 DOCS_LATEST = DOCS_BASE_URL % "latest"
 DOCS_BASE_URL %= BRANCH_NAME if BRANCH_NAME != "master" else "latest"
@@ -171,6 +172,15 @@ David Pérez Carmona
 Jakub Wilk
 IBBoard@github
 CreamyCookie@github
+Sauyon Lee
+Thomas Leberbauer
+Kristian Laakkonen
+Emanuele Baldino
+Peter F. Patel-Schneider
+Pete Beardmore
+Muges@github
+Meriipu@github
+Jonas Platte
 """.strip().split("\n"))
 
 TRANSLATORS = sorted(u"""
@@ -232,6 +242,8 @@ scootergrisen@github (da)
 Marek Suchánek (cs)
 Till Berger (de)
 Jean-Michel Pouré (fr)
+Kristian Laakkonen (fi)
+Kirill Romanov (ru)
 """.strip().splitlines())
 
 ARTISTS = sorted(u"""\
