@@ -4,8 +4,9 @@
 #           2013,2014 Christoph Reiter
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 """Base library classes.
 
@@ -34,7 +35,7 @@ from quodlibet.util.dprint import print_d, print_w
 from quodlibet.util.path import unexpand, mkdir, normalize_path, ishidden, \
     ismount
 from quodlibet.compat import iteritems, iterkeys, itervalues, listkeys, \
-    listvalues
+    listvalues, listfilter
 
 
 class Library(GObject.GObject, DictMixin):
@@ -460,12 +461,12 @@ class SongLibrary(PicklingLibrary):
 
     def query(self, text, sort=None, star=Query.STAR):
         """Query the library and return matching songs."""
-        if isinstance(text, str):
+        if isinstance(text, bytes):
             text = text.decode('utf-8')
 
         songs = self.values()
         if text != "":
-            songs = filter(Query(text, star).search, songs)
+            songs = listfilter(Query(text, star).search, songs)
         return songs
 
 
@@ -654,7 +655,7 @@ class FileLibrary(PicklingLibrary):
             if ismount(point):
                 self._contents.update(items)
                 del(self._masked[point])
-                self.emit('added', items.values())
+                self.emit('added', listvalues(items))
                 yield True
 
         task = Task(_("Library"), _("Scanning library"))
@@ -834,6 +835,10 @@ class SongFileLibrary(SongLibrary, FileLibrary):
         key = normalize_path(filename, True)
         return key in self._contents
 
+    def get_filename(self, filename):
+        key = normalize_path(filename, True)
+        return self._contents.get(key)
+
     def add_filename(self, filename, add=True):
         """Add a song to the library based on filename.
 
